@@ -9,10 +9,7 @@
 # Copyright (c) 2003 by kaepapa <kaepapa@kaepapa.dip.jp>
 
 # grubmenu version
-VERSION = "grubmenu 0.2.0"
-
-# grubmenugui version
-GUIVERSION = "grubmenugui 0.0.1"
+VERSION = "grubmenu 0.2.4"
 
 # boot directory
 BOOT = "/boot"
@@ -26,8 +23,14 @@ GRUB_DIRS = ['/boot/grub/','/boot/boot/grub/']
 # path to fstab file
 FSTAB_FILE = "/etc/fstab"
 
+# version files list
+VER_FILES = [['/etc/debian_version','DebianGNU/Linux'],
+             ['/etc/vine-release','Vine Linux'],
+             ['/etc/redhat-release','Redhat Linux'],
+             ['/etc/gentoo-release','Gentoo Linux']]
+
 # the character color on the grub menu
-STR_COLOR = ['black','bule','blue','green','cyan','red','magenta','brown','light-gray','dark-gray',\
+STR_COLOR = ['black','blue','green','cyan','red','magenta','brown','light-gray','dark-gray',\
          'light-blue','light-green','light-cyan','light-red','light-magenta','yellow','white']
 
 # the background color on the grub menu
