@@ -96,7 +96,7 @@ class ui_wxPython(wxFrame):
         self.combo_box_defaultboot = wxComboBox(self.notebook_common, -1,
                                                choices=self.__conf.VM_LIST,
                                                style=wxCB_DROPDOWN|wxCB_READONLY)
-        self.label_windows = wxStaticText(self.notebook_common, -1, _("Windows Entry (ex. /dev/hda1 or hd(0,0))"))
+        self.label_windows = wxStaticText(self.notebook_common, -1, _("Windows Entry (ex. /dev/hda1)"))
         self.text_ctrl_windows = wxTextCtrl(self.notebook_common, -1, "")
         self.checkbox_splash = wxCheckBox(self.notebook_appearance, ID_CHKBOX_SPLASH, _("Splash"))
         self.text_ctrl_splash = wxTextCtrl(self.notebook_appearance, -1, "")
@@ -303,7 +303,7 @@ class ui_wxPython(wxFrame):
                                   "Caution!", wxOK | wxICON_EXCLAMATION)
             dlg.ShowModal()
             dlg.Destroy()
-            self.text_ctrl_windows.SetValue(utils.recover_device_name(self.__conf.WIN))
+            self.text_ctrl_windows.SetValue(self.__conf.WIN)
             self.notebook_guiconfig.SetSelection(0)
             
         # save timeout
@@ -333,19 +333,16 @@ class ui_wxPython(wxFrame):
 
         # save windows entry
         dev = self.text_ctrl_windows.GetValue()
-        if re.match("^hd\([0-8],[0-9]+\)", dev) != None:
+        if re.match("^/dev/.*", dev) != None:
+            try:
+                __dev = utils.dev_name_exchange(dev)
+                self.__conf.WIN = dev
+            except:
+                badDevice()
+        elif dev == '':
             self.__conf.WIN = dev
         else:
-            if re.match("^/dev/.*", dev) != None:
-                try:
-                    self.__conf.WIN = utils.dev_name_exchange(dev)
-                except:
-                    badDevice()
-            else:
-                if dev == '':
-                    self.__conf.WIN = dev
-                else:
-                    badDevice()
+            badDevice()
                     
         # save splash
         if self.checkbox_splash.GetValue():
@@ -396,7 +393,7 @@ class ui_wxPython(wxFrame):
 
     # onClick event method of options button
     def OnBtnOptionsClick(self, event):
-        dlg = wxFileDialog(self, "Choose a file", "/", "", "*.xpm", wxOPEN)
+        dlg = wxFileDialog(self, "Choose a file", "/", "", "XPM archive(*.xpm.gz)|*.xpm.gz|XPM file(*.xpm)|*.xpm", wxOPEN)
         if dlg.ShowModal() == wxID_OK:
             filename = dlg.GetFilename()
             directory = dlg.GetDirectory()
@@ -446,8 +443,8 @@ class ui_wxPython(wxFrame):
                 self.combo_box_single_mode.SetSelection(self.__conf.VM_LIST.index(img)+1)
                 
         # set boot option
+        self.grid_entry.AppendRows(len(self.__conf.VM_LIST), False)
         for opt_list in self.__conf.OPTION_LIST:
-            self.grid_entry.AppendRows(1,false)
             self.grid_entry.SetCellValue(self.__conf.VM_LIST.index(opt_list[0]), 0, opt_list[0])
             self.grid_entry.SetReadOnly(self.__conf.VM_LIST.index(opt_list[0]), 0, True)
             option = ''
